:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

Grappelli 5.0.x Release Notes
=============================

**Grappelli 5.0.x is compatible with Django 6.0**.

Update from Grappelli 4.x
-------------------------

* Update Django to 6.x and check the Django release notes
* Update Grappelli to 5.x
